<?php
/**
 * Classe da manipulacao de situacao da atividade da Apropriacao da Atividade.
 *
 * @package Logic
 * @author  walterrodrigues
 */
class GepApropriacaoAtividadeLogic {

	
    /**
     * Codigo da atividade de processamento Programacao.
     * @var unknown_type
     */
    const ID_TIPO_ATIVIDADE_PROGRAMACAO = 8;
    
    /**
     * Identificador do tipo de operacao setforms.
     */
    const ID_TIPO_OPERACAO_FRAMEWORK = 'framework';
    
    /**
     * Identificados do tipo de operacao produtos.
     */
    const ID_TIPO_OPERACAO_PRODUTOS = 'produtos';
    
    /**
     * Identificador do item de trabalho do tipo metadados.
     */
    const ID_ITEM_TRABALHO_METADADOS = 'metadados';
    
    /**
     * Identificador do item de trabalho do tipo arquivo.
     */
    const ID_ITEM_TRABALHO_ARQUIVO = 'file';
    
    /**
     * Identificador do caminho do item de trabalho.
     */
    const ID_CAMINHO_ITEM_TRABALHO = 'caminho';
    
    /**
     * Nome do ambiente de desenvolvimento setforms.
     */
    const AMBIENTE_DESENVOLVIMENTO_SETFORMS = 'SETFORMS_DESENVOLVIMENTO';
    
    /**
     * Nome do ambiente de desenvolvimento de produtos.
     */
    const AMBIENTE_DESENVOLVIMENTO_PRODUTOS = 'PRODUTOS_DESENVOLVIMENTO';
    
    
    /**
	 * Atualiza os arquivos da maquina local.
	 * 
	 * @param string $tipoAtualizacao
	 * 
	 * @return boolean
	 */
	public static function atualizarArquivosLocal($nmAcessoOperador, $tipoAtualizacao) {
        $urlGcs = GcsClientLogic::retornaUrlGcsLocal();
        $urlServico = "{$urlGcs}?servico=".GcsClientLogic::SERVICO_ATUALIZAR_REMOTO;
      	$urlServico.= "&usuario={$nmAcessoOperador}";
      	$urlServico.= "&tipoOperacao={$tipoAtualizacao}";
    	$request = GcsClientLogic::remoteRequest($urlServico);
    	$result = (preg_match('/^OK$/', $request) > 0) ? true : false;

    	return $result;
    }
     
    
    public static function validaAtividade($codAtividade) {
    	$codOrganizacao = Ambiente::getNrorg();
    	if (empty($codAtividade) === true || (is_numeric($codAtividade) === false)) {
            throw new Exception(tk_get_message_by_name('msg_apr_erro_cod_ativ_invalido'));
        }

        $objAtividade = GepAtividade::getObjectByWhere(
            'NRATIVIDADE = ? AND NRORG = ?', 
            array($codAtividade, $codOrganizacao)
        );
        $tipoDeAtividade = $objAtividade->getNratividadeproc();
        if (($objAtividade instanceof GepAtividadeEntity) === false) {
            throw new Exception(tk_get_message_by_name('msg_apr_erro_ativ_nao_encontrada', array($codAtividade)));
        }
        
        $nomeAmbiente = GepAmbienteEntity::retornaAmbienteAtividade($codAtividade);
        $ambientes = array(
            self::AMBIENTE_DESENVOLVIMENTO_PRODUTOS, 
            self::AMBIENTE_DESENVOLVIMENTO_SETFORMS
        );
        if (in_array($nomeAmbiente, $ambientes) === true) {
            if (empty ($tipoDeAtividade) === true) {
                throw new Exception(tk_get_message_by_name('msg_apr_erro_ativ_desenv_sem_tipoativ'));
            }
        }
        
        if ($tipoDeAtividade === (int)self::ID_TIPO_ATIVIDADE_PROGRAMACAO) {
            if (self::atividadePossuiSolicitacao($objAtividade) === false) {
                throw new Exception(tk_get_message_by_name('msg_apr_erro_ativ_prog_sem_solicitacao'));
            }
            
            /* Inativo
            $itens = self::atividadePossuiItemDeTrabalho($objAtividade);
            if (empty($itens) === true) {
                throw new Exception(tk_get_message_by_name('msg_apr_erro_ativ_sem_itemtrab', array($codAtividade)));
            }
            */
        }
        
        return $objAtividade;
    }


    /**
     * Apropria a atividade pela primeira vez.
     *
     * @param integer $codAtividade       Cod da atividade.
     * @param string  $nomeAtividade   Nome da atividade.
     * @param string  $codOperadorResp        Cod do operador responsavel.
     * @param string  $dataInicialPlanejada Data de inicio do planejamento.
     * @param string  $dataFinalPlanejada    Data fim do planejamento.
     *
     * @throws Exception Lanca exececao caso a atividade seja invalida.
     * @return boolean
     */
    public static function iniciarAtividade(
        $codAtividade,
        $nomeAtividade,
        $codOperadorResp = null,
        $dataInicialPlanejada = null,
        $dataFinalPlanejada = null
    ) {
        
        $codOrganizacao = Ambiente::getNrorg();
		$objAtividade = self::validaAtividade($codAtividade);
        switch ($objAtividade->getIdsituacaoativ()) {
        case GepAtividade::SITUACAO_PENDENTE:
           // intencional: sem break aqui.
        case GepAtividade::SITUACAO_INTERROMPIDA:
            // Atividades realizadas podem voltar caso ocorram problemas no teste em par.
        case GepAtividade::SITUACAO_REALIZADA:
            $atividadeEmAndamento  = GepAtividadeEntity::retornaAtividadeAndamento($codOrganizacao, $codOperadorResp);
            if (is_array($atividadeEmAndamento) === true) {
                $codAtiviadeEmAndamento = $atividadeEmAndamento['NRATIVIDADE'];
                GepApropriacaoAtividadeLogic::paralisarAtividade($codAtiviadeEmAndamento);
            }

            $situacaoAtividade = GepAtividade::SITUACAO_ANDAMENTO;
            $dataInicialPlanejada = now();
            GepAtividadeEntity::alteraStatusAtvidade(
                $situacaoAtividade,
                $codOrganizacao,
                $codAtividade
            );

            GepApropriacaoEntity::insereApropriacao(
                $codAtividade,
                $dataInicialPlanejada,
                $dataFinalPlanejada,
                $dataInicialPlanejada,
                $dataFinalPlanejada
            );

            return true;
        default:
            $situacoesPermitidas = implode(
            	',', 
            	array(
            		GepAtividade::SITUACAO_PENDENTE, 
            		GepAtividade::SITUACAO_INTERROMPIDA, 
            		GepAtividade::SITUACAO_REALIZADA)
            );
            
            throw new Exception(tk_get_message_by_name('msg_apr_validacao_status_apropriacao', array($situacoesPermitidas)));
        }

    }


    /**
     * Interrompe uma atividade em andamento.
     *
     * @param string $codAtividade Codigo da atividade.
     *
     * @return boolean
     */
    public static function paralisarAtividade($codAtividade) {
        $codOrganizacao = Ambiente::getNrorg();
        $filtro = array(
            $codAtividade,
            $codOrganizacao,
        );

        $objAtividade = self::validaAtividade($codAtividade);
        switch ($objAtividade->getIdsituacaoativ()) {
        case GepAtividade::SITUACAO_ANDAMENTO:
            $situacaoAtividade = GepAtividade::SITUACAO_INTERROMPIDA;
            $dataFinalPlanejada = now();
            $objApropriacao = GepApropriacao::retornaInsertApropriacao($codAtividade);
            if (($objApropriacao instanceof GepApropriacaoEntity) !== true) {
                throw new Exception(tk_get_message_by_name('msg_apr_erro_ativ_sem_apropriacao', array($codAtividade)));
            }

            $nrapropriacao = $objApropriacao->getNrapropriacao();
            GepApropriacao::alteraDtfimaproReal($dataFinalPlanejada, $codAtividade, $nrapropriacao);
            GepAtividadeEntity::alteraStatusAtvidade($situacaoAtividade, Ambiente::getNrorg(), $codAtividade);

            return true;

        default:
            throw new Exception(tk_get_message_by_name('msg_apr_validacao_status_apropriacao', array(GepAtividade::SITUACAO_ANDAMENTO)));
        }

    }
    
    
    public static function retornaTipoOperacao($codAtividade) {
        $nomeAmbiente = GepAmbienteEntity::retornaAmbienteAtividade($codAtividade);
        if (empty($nomeAmbiente) === true) {
            throw new Exception(tk_get_message_by_name('msg_apr_solicitacao_nao_possui_ambiente'));
        }
        
        if ($nomeAmbiente === self::AMBIENTE_DESENVOLVIMENTO_PRODUTOS) {
            return self::ID_TIPO_OPERACAO_PRODUTOS;
        } 
        
        return self::ID_TIPO_OPERACAO_FRAMEWORK;
    }
    
    
    public static function constroiUrlServicoConclusaoAtiv($codAtividade, $observacaoAtividade, array $itensAtividade) {
        $urlGcs = GcsClientLogic::retornaUrlGcsLocal();
        $servico = GcsClientLogic::SERVICO_CONCLUIR_REMOTO;
        $tipoOperacao = self::retornaTipoOperacao($codAtividade);
        $urlServico = "{$urlGcs}?servico={$servico}";
        $urlServico.= '&usuario='.urlencode(Ambiente::getNmacesso());
        $urlServico.= '&tipoOperacao='.urlencode($tipoOperacao);
        $urlServico.= '&codAtividade='.urlencode($codAtividade);
        $urlServico.= '&descricaoCommit='.urlencode($observacaoAtividade);
        $itensParaExportar = array();
        foreach ($itensAtividade as $itens) {
            $itensParaExportar[] = $itens['FILE'];
        }
        
        $urlServico.= '&itensTrabalho='.urlencode(implode(',', $itensParaExportar));
        return $urlServico;
    }
    


    /**
     * Exporta itens da atividade e a define como realizada.
     *
     * @param string $codAtividade Cod da atividade.
     *
     * @throws Exception Lanca excecao caso a atividade seja invalida.
     *
     * @return boolean
     */
    public static function realizarAtividade($codAtividade) {
        /* Inativo.
        $codOrganizacao = Ambiente::getNrorg();
        $objAtividade = self::validaAtividade($codAtividade);
		switch ($objAtividade->getIdsituacaoativ()) {
        case GepAtividade::SITUACAO_ANDAMENTO:
        case GepAtividade::SITUACAO_INTERROMPIDA:
            $resultadoRequisicao = false;
            try {
                if ((int)$objAtividade->getNratividadeproc() === (int)self::ID_TIPO_ATIVIDADE_PROGRAMACAO) {
                    $itensAtividade = self::retornaItensTrabalhoAtividade($codAtividade);
        			if ((count($itensAtividade[self::ID_ITEM_TRABALHO_METADADOS]) > 0 ||
                        count($itensAtividade[self::ID_ITEM_TRABALHO_ARQUIVO]) > 0 )) {
                        $itensRealizados = array();
                        $itensRealizados[$codAtividade] = $itensAtividade;
                        $caminhoMaquinaLocal = self::retornaCaminhoAtividadeMaquinaLocal($codAtividade);
                        $itensRealizados[$codAtividade][self::ID_CAMINHO_ITEM_TRABALHO] = $caminhoMaquinaLocal;
                    }
                    
					$dataInclusaoAtividade = new Zend_Date($objAtividade->getDtinclusao());
                    $urlServico = self::constroiUrlServico(
                        GcsClientLogic::SERVICO_REALIZAR_REMOTO, 
                        $itensRealizados, 
                        $dataInclusaoAtividade
                    );
                    $resultadoRequisicao = GcsClientLogic::remoteRequest($urlServico);
                    $resultadoRequisicao = (preg_match('/^OK$/', $resultadoRequisicao) > 0) ? true : false;
                }

                if ($resultadoRequisicao === true) {
                    GepAtividadeEntity::alteraStatusAtvidade(
                        GepAtividade::SITUACAO_REALIZADA,
                        $codOrganizacao,
                        $codAtividade
                    );
                }

                return $resultadoRequisicao;
            } catch (Exception $e) {
                throw $e;
            }
        default:
            $situacoesPermitidas = implode(
            	',', 
            	array(
            		GepAtividade::SITUACAO_ANDAMENTO, 
            		GepAtividade::SITUACAO_INTERROMPIDA 
            	)
            );
            
            throw new Exception(
                tk_get_message_by_name(
                    'msg_apr_validacao_status_ativ_realizada', 
                    array($situacoesPermitidas)
            ));
        }
     */
    }


    /**
     * Funcao para mudar a situacao da atividade para Concluida.
     *
     * @param string $codAtividade Cod atividade.
     * @param string $observacaoAtividade Resumo do que foi feito na atividade.
     * @param array $listaArquivos Lista de arquivos que serao submetidos ao 
     * servidor svn.
     *
     * @return boolean
     */
    public static function concluirAtividade($codAtividade, $observacaoAtividade, array $listaArquivos = array()) {
        $conexaoBanco = \Setforms2\Runtime\Connection::getInstance()->getConn();
        $codOrganizacao = Ambiente::getNrorg();
        $objAtividade = self::validaAtividade($codAtividade);
        switch ($objAtividade->getIdsituacaoativ()) {
        case GepAtividade::SITUACAO_ANDAMENTO:
            try {
                if ((int)$objAtividade->getNratividadeproc() === (int)self::ID_TIPO_ATIVIDADE_PROGRAMACAO) {
                    $listaArquivosRetornada = array();
                    if (empty($listaArquivos) === false) {
                        $urlServico = self::constroiUrlServicoConclusaoAtiv(
                            $codAtividade,
                            utf8_decode($observacaoAtividade),    
                            $listaArquivos 
                        );
                    
                        $resultadoRequisicao = GcsClientLogic::remoteRequest($urlServico);
                        $listaArquivosRetornada = json_decode($resultadoRequisicao, true);
                    }
                }
                
                if (empty($listaArquivos) === false && empty($listaArquivosRetornada) === true) {
                    return false;
                }
                
                $conexaoBanco->beginTransaction();
                $objAtividade->setTxobservatividade($observacaoAtividade);
                $objAtividade->persist();
                
                if (empty ($listaArquivosRetornada) === false) {
                    self::persistirArquivosItensTrabalho(
                        $codAtividade, 
                        $listaArquivosRetornada
                    );
                }
                
                $situacaoAtividade = GepAtividade::SITUACAO_CONCLUIDA;
                $dataConclusao = now();
                $objApropriacao = GepApropriacao::retornaInsertApropriacao($codAtividade);
                if (($objApropriacao instanceof GepApropriacaoEntity) === false) {
                    throw new Exception(tk_get_message_by_name('msg_apr_erro_ativ_sem_apropriacao', array($codAtividade)));
                }

                $codApropriacao = $objApropriacao->getNrapropriacao();
                GepApropriacao::alteraDtfimaproReal(
                    $dataConclusao,
                    $codAtividade,
                    $codApropriacao
                );
                
                $atividadeEntity = GepAtividadeEntity::retornaDadosAtividade($codOrganizacao, $codAtividade);
                $atividadeEntity->setIdsituacaoativ($situacaoAtividade);
                $atividadeEntity->setDtfinalizacao($dataConclusao);
                $atividadeEntity->persist();
                
                return $conexaoBanco->commit();
            } catch (Exception $e) {
                $conexaoBanco->rollback();
                throw $e;
            }

        default:
            throw new Exception(
                tk_get_message_by_name(
                    'msg_apr_validacao_status_ativ_concluida', 
                    array(GepAtividade::SITUACAO_ANDAMENTO)
                )
            );
        }
    }
    

    /**
     * Retorna Recur Arvore.
     *
     * @param string $codArvorePai Codigo da arvore do pai.
     *
     * @return ArrayObject
     */
    public static function retornaArvoreRecursivamente($codArvorePai, &$caminhos = array()) {
        /* Inativo
        $codOrganizacao = Ambiente::getNrorg();
        if ($codArvorePai === null) {
            return $caminhos;
        } else {
            $objArvore = Arvore::retornaArvore($codArvorePai, 'GEP_ITEMTRABALHO', $codOrganizacao);
            $nomeDaArvore = $objArvore->getNmarvore();
            $codArvorePai = $objArvore->getNrarvorepai();
            $caminhos[] = $nomeDaArvore;
            
            return self::retornaArvoreRecursivamente($codArvorePai);
        }
        */
    }
    
    /**
     * Retorna a versao corrente do setforms.
     * 
     * @return string 
     */
    public static function retornaVersaoCorrenteSetforms() {
        $versaoSetforms = GepAmbienteLogic::retornaParametroAmbiente(
            'VERSAO_SETFORMS', 
            self::AMBIENTE_DESENVOLVIMENTO_SETFORMS
        );
        
        if (empty($versaoSetforms) === true) {
            throw new Exception(
                tk_get_message_by_name(
                    'msg_apr_param_ambiente_nao_cadastrado', 
                    array('VERSAO_SETFORMS', self::AMBIENTE_DESENVOLVIMENTO_SETFORMS)
                )
            );
        }
        
        return $versaoSetforms;
    }
    
    
    /**
     * Retorna a versao corrente de produtos.
     * 
     * @return string 
     */
    public static function retornaVersaoCorrenteProdutos() {
        $versaoProdutos = GepAmbienteLogic::retornaParametroAmbiente(
            'VERSAO_DESENVOLVIMENTO', 
            self::AMBIENTE_DESENVOLVIMENTO_PRODUTOS
        );
        
        if (empty($versaoProdutos) === true) {
            throw new Exception(
                tk_get_message_by_name(
                    'msg_apr_param_ambiente_nao_cadastrado', 
                    array('VERSAO_PRODUTOS', self::AMBIENTE_DESENVOLVIMENTO_PRODUTOS)
            ));
        }
        
        return $versaoProdutos;
    }
    
    
    /**
     * Retorna a url do repositorio svn.
     * 
     * @return string
     */
    public static function retornaUrlRepositorioSvn() {
        /* Inativo
        $urlRepositorioSvn = GepAmbienteLogic::retornaParametroAmbiente(
            'URL_REPOSITORIO_SVN_PRODUTOS', 
            self::AMBIENTE_GERENCIA_CONFIGURACAO
        );
        
        if (empty($urlRepositorioSvn) === true) {
             throw new Exception(
                tk_get_message_by_name(
                    'msg_apr_param_ambiente_nao_cadastrado', 
                    array('URL_REPOSITORIO_SVN_PRODUTOS', self::AMBIENTE_GERENCIA_CONFIGURACAO)
            ));
        }
        
        return $urlRepositorioSvn;
        */
    }
    
    
   /**
     * Retorna caminho completo do arquivo do item de trabalho.
     *
     * @param string $objItemtrabalho Item de trabalho da atividade.
     *
     * @return string
     */
    public static function retornaCaminhoItemTrabalho(GepItemtrabalhoEntity $objItemtrabalho) {
        /* Inativo
        $caminhoItemTrabalho = '';
        $codArvorePai = $objItemtrabalho->getNrarvorepai();
        $objArvore = self::retornaArvoreRecursivamente($codArvore);
        $versaoProdutos = self::retornaVersaoCorrenteProdutos();
        $versaoSetforms = self::retornaVersaoCorrenteSetforms();
        if (isset($objArvore) === false) {
            throw new Exception ('Não foi possível recuperar o caminho da árvore ('.$codArvore.')');
        }

        foreach ($objArvore as $indice => $valorArvore) {
            $caminhoItemTrabalho = DIRECTORY_SEPARATOR.$valorArvore.$caminhoItemTrabalho;
        }
        
        $caminhoItemTrabalho = substr($caminhoItemTrabalho, 1);
        $paraSubstituir = array(
            'products/v_'.$versaoProdutos.'/',
            'setforms/v_'.$versaoSetforms.'/',
        );
        $caminhoItemTrabalho = str_replace(array('products/', 'setforms/'), $paraSubstituir, $caminhoItemTrabalho);
        
        return $caminhoItemTrabalho;
        */
    }

    
    /**
     * Verifica se uma atividade do tipo desenvolvimento possui.
     *
     * @param GepAtividadeEntity $objAtividade Objeto da tabela GEP_ATIVIDADE.
     *
     * @return boolean
     */
    public static function atividadePossuiSolicitacao(GepAtividadeEntity $objAtividade) {
        $codSolicitacao = $objAtividade->getNrsolicitacao();
        return (empty($codSolicitacao) === false) ? true : false;
    }

    
    /**
     * Verifica se a atividade possui itens de trabalho.
     *
     * @param mixed $objAtividade Objeto da tabela GEP_ATIVIDADE.
     *
     * @return boolean|array
     */
    public static function atividadePossuiItemDeTrabalho(GepAtividadeEntity $objAtividade) {
        // se nao ha itemtrabalhoativ, nao atualiza nada.
        $codAtividade = $objAtividade->getNratividade();
        $filtro = array(
            $objAtividade->getNrorg(),
            $codAtividade,
        );
        $itens = GepItemtrabalhoativ::getObjectsByWhere('NRORG = ? AND NRATIVIDADE = ?', $filtro);
        return (empty($itens) === false) ? $itens : false;
    }
    
    
    /**
     * Retorna o sql da consulta dos itens de trabalho de uma atividade.
     * 
     * @param int $codAtividade Cod. da Atividade.
     * 
     * @return string
     */
    public static function retornaConsultaItensTrabalhoAtiv($codAtividade) {
    	$sql = GepItemtrabalhoativEntity::retornaConsultaItensTrabalhoAtiv($codAtividade);
    	return $sql;
    }  
    
  
    /**
     * Retorna todos os itens de uma atividade (metadados/arquivos).
     * 
     * @param string $codAtividade
     * 
     * @return string 
     */
    public static function retornaItensTrabalhoAtividade($codAtividade) {
        $itensAtividade = array();
        $codOrganizacao = Ambiente::getNrorg();
        $itens = GepItemtrabalhoativ::getObjectsByWhere(
            "NRORG = ? AND NRATIVIDADE = ?", 
            array($codOrganizacao, $codAtividade)
        );
        
        foreach ($itens as $item) {
            $descricaoItem = $item->get('DSITEMTRABALHO');
            if (empty($descricaoItem) === false) {
                // metadata
                $itensAtividade[self::ID_ITEM_TRABALHO_METADADOS][] = $descricaoItem;
            } else {
                // files
                $nritemtrabalho = $item->get('NRITEMTRABALHO');
                if (empty($nritemtrabalho) !== true) {
                    $objItemtrab = GepItemtrabalho::getObjectByWhere("NRORG = ? AND NRITEMTRABALHO = ?", array($codOrganizacao, $nritemtrabalho));
                    if (($objItemtrab instanceof GepItemtrabalhoEntity) === true) {
                        $caminhoRemoto = self::retornaCaminhoItemTrabalho($objItemtrab);
                        $itensAtividade[self::ID_ITEM_TRABALHO_ARQUIVO][] = $caminhoRemoto . '/' . $objItemtrab->getNmitemtrabalho();
                    }
                }
            }
        }
        
        return $itensAtividade;
    }
    
    
    /**
     * Retorna caminho da atividade na maquina local.
     *
     * @param string $codAtividade
     * 
     * @return string
     */
    public static function retornaCaminhoAtividadeMaquinaLocal($codAtividade) {
        /* Inativo
        $objAtividade = GepAtividadeLogic::retornaAtividade($codAtividade);
        $caminhoAtivLocal = GcsClientLogic::CAMINHO_DIR_ATIVIDADES_LOCAL;
        $codSolicitacao = ($objAtividade->getNrsolicitacao() > 0) ? $objAtividade->getNrsolicitacao() : '0';
        $caminhoAtivLocal .= $codSolicitacao.'/'.$codAtividade.'_'.$objAtividade->getNrorg().'/';
        return $caminhoAtivLocal;
        */
    }
    
    
    /**
     * Retorna a url do servico de arquivos modificados localmente.
     * 
     * @return string 
     */
    public static function retornaUrlServicoArquivosModificados($codAtividade) {
        $codOperador = Ambiente::getCdOperador();
        $objOperador = Operador::consultaOperador($codOperador);
        $tipoOperacao = self::retornaTipoOperacao($codAtividade);
        $nmAcessoOperador = $objOperador->getNmacesso();
        $urlGcs = GcsClientLogic::retornaUrlGcsLocal();
        $urlServico = $urlGcs."?servico=CheckLocalModifications&usuario={$nmAcessoOperador}&tipoOperacao={$tipoOperacao}";
        return $urlServico;
    }
    
    
    /**
     * Adiciona os arquivos alterados localmente como itens de trabalho da atividade.
     * 
     * @param string $codAtividade Codigo da atividade.
     * @param array $listaArquivos Lista de arquivos que serao incluidos na atividade.
     */
    public static function persistirArquivosItensTrabalho($codAtividade, array $listaArquivos) {
        $codigoOrganizacao = Ambiente::getNrorg();
        $codigoOperador = Ambiente::getCdOperador();
        foreach ($listaArquivos as $arquivo) {
            $descricaoItemTrab = explode("\\", $arquivo['FILE']);
            unset(
                $descricaoItemTrab[0], 
                $descricaoItemTrab[1], 
                $descricaoItemTrab[2], 
                $descricaoItemTrab[4]
            );
            $descricaoItemTrab = implode("\\", $descricaoItemTrab);
            $revisaoAnterior = $arquivo['OLD_REVISION'];
            $revisaoAtual = $arquivo['NEW_REVISION'];
            $novoCodigo = GepItemtrabalhoativEntity::retornaNovoCodigo(Ambiente::getNrorg());
            $objItemTrabalhoAtivEntity = new GepItemtrabalhoativEntity();
            $objItemTrabalhoAtivEntity->setNritemtrabalhoativ($novoCodigo);
            $objItemTrabalhoAtivEntity->setNratividade($codAtividade);
            $objItemTrabalhoAtivEntity->setNrorg($codigoOrganizacao);
            $objItemTrabalhoAtivEntity->setNrorginclusao($codigoOrganizacao);
            $objItemTrabalhoAtivEntity->setNrorgultatu($codigoOrganizacao);
            $objItemTrabalhoAtivEntity->setDsitemtrabalho($descricaoItemTrab);
            $objItemTrabalhoAtivEntity->setNrreleaseanterior($revisaoAnterior);
            $objItemTrabalhoAtivEntity->setNrreleaseatual($revisaoAtual);
            $objItemTrabalhoAtivEntity->setCdoperinclusao($codigoOperador);
            $objItemTrabalhoAtivEntity->setCdoperultatu($codigoOperador);
            $objItemTrabalhoAtivEntity->setIdativo('S');
            $objItemTrabalhoAtivEntity->setDtinclusao(now());
            $objItemTrabalhoAtivEntity->setDtultatu(now());
            $objItemTrabalhoAtivEntity->persist();
        }
    }
    

    /**
      * Insere na tabela Apropriacao.
      *
      * @param string $nratividade         Numero da atividade.
      * @param string $dtinicioapropriacao Data de inicio da apropriacao.
      * @param string $dtfimapropriacao    Data de finalizacao da apropriacao.
      * @param string $dtinicioaproprireal Data de inicio da apropriacao real.
      * @param string $dtfimaproprireal    Data de finalizacao da apropriacao rel.
      *
      * @return void
     */
    public static function insereApropriacao(
        $nratividade,
        $dtinicioapropriacao,
        $dtfimapropriacao,
        $dtinicioaproprireal,
        $dtfimaproprireal
    ){
        GepApropriacaoEntity::insereApropriacao(
            $nratividade,
            $dtinicioapropriacao,
            $dtfimapropriacao,
            $dtinicioaproprireal,
            $dtfimaproprireal
        );
    }


    /**
     * Retorna dados da apropriacao pela atividade.
     *
     * @param integer $nrorg       Numero da Organizacao.
     * @param integer $nratividade Numero da Atividade.
     *
     * @return Ambigous <<type>, multitype:, mixed>|boolean
     */
    public static function consultaDadosApropriacaoByAtividade($nrorg, $nratividade){
        $dados = GepApropriacaoEntity::consultaDadosApropriacaoByAtividade($nrorg, $nratividade);
        return $dados;
    }


    /**
     * Altera Apropriacao.
     *
     * @param integer $nrparcoperresp      Numero do Parceiro.
     * @param integer $nratividade         Numero da atividade.
     * @param string  $dtinicioapropriacao Data de inicio da apropriacao.
     * @param string  $dtfimapropriacao    Data fim da apropriacao.
     * @param string  $dtultatu            Data de atualizacao.
     * @param string  $nrorgultatu         Numero da organizacao do operador que atualizou.
     * @param string  $cdoperadorultatu    Codigo do operador que realizou a atualizacao.
     * @param integer $nrorg               Numero da organizacao.
     *
     * @return boolean
     */
    public static function alteraApropriacao(
         $nrparcoperresp, $nratividade,
        $dtinicioapropriacao, $dtfimapropriacao, $dtultatu,
        $nrorgultatu, $cdoperadorultatu, $nrorg
    ){
        $retorno = GepApropriacaoEntity::alteraApropriacao(
            $nrparcoperresp, $nratividade, $dtinicioapropriacao,
            $dtfimapropriacao, $dtultatu, $nrorgultatu,
            $cdoperadorultatu, $nrorg
        );
        return $retorno;
    }


    /**
     * Retorna datas das apropriacoes.
     *
     * @param string  $nrparcoperresp Numero do parceiro responsavel.
     * @param date    $dtIni          Data inicial.
     * @param date    $dtFim          Data de termino.
     * @param integer $nrorg          Numero da organizacao.
     *
     * @return boolean
     */
    public static function retornaDatasDasApropriacoes($nrparcoperresp, date $dtIni, date $dtFim, $nrorg){
        $consulta = GepApropriacaoEntity::retornaDatasDasApropriacoes($nrparcoperresp, $dtIni, $dtFim, $nrorg);
        return $consulta;
    }


    /**
     * Exclui Apropriacao por atividade.
     *
     * @param integer $nrorg       Numero da Organizacao.
     * @param integer $nratividade Numero da Atividade.
     *
     * @return Ambigous <number, number>
     */
    public static function excluiApropriacaoByAtividade($nrorg, $nratividade){
        $dado = GepApropriacaoEntity::excluiApropriacaoByAtividade($nrorg, $nratividade);
        return $dado;
    }


    /**
     * Consulta datas de apropriacao.
     *
     * @param string $nrparcoperresp  Numero do operador responsavel.
     * @param string $dtinicioreuniao Data de inicio da reuniao.
     * @param string $nrorg           Numero da organizacao.
     *
     * @return Ambigous <mixed, NULL>|boolean
     */
    public static function consultaDataApropriacao($nrparcoperresp, $dtinicioreuniao, $nrorg) {
        $apropriacao = GepApropriacaoEntity::consultaDataApropriacao($nrparcoperresp, $dtinicioreuniao, $nrorg);
        return $apropriacao;

    }


    /**
     * Retorna o proximo codigo novo da apropriacao.
     *
     * @param integer $nrorg Numero da Organizacao.
     *
     * @return integer
     */
    public static function novoCodigoApropriacao($nrorg){
        $codigo = GepApropriacaoEntity::geraNovoCodigoApropriacao($nrorg);
        return $codigo;
    }
 
}